@@ -1,11 +1,10 @@
 package Echolot::Stats;
 
 #
-# $Id: Stats.pm 631 2004-04-28 11:58:25Z weasel $
 #
 # This file is part of Echolot - a Pinger for anonymous remailers.
 #
-# Copyright (c) 2002, 2003, 2004 Peter Palfrader <peter@palfrader.org>
+# Copyright (c) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2012, 2014 Peter Palfrader <peter@palfrader.org>
 #
 # This program is free software. you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +18,7 @@ package Echolot::Stats;
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 #
 
 =pod
@@ -876,8 +875,8 @@ sub build_pgpring_type($$$$) {
 		if ( defined Echolot::Globals::get()->{'storage'}->get_nick($addr) ) {
 			my ( $stdin_fh, $stdout_fh, $stderr_fh, $status_fh, $handles ) = Echolot::Tools::make_gpg_fds();
 			my $pid = $GnuPG->wrap_call(
-				commands     => [ '--import' ],
-				command_args => [qw{--no-options --no-secmem-warning --no-default-keyring --fast-list-mode --keyring}, $keyring, '--', '-' ],
+				commands     => [qw{--no-options --no-secmem-warning --no-default-keyring --fast-list-mode --keyring}, $keyring, '--import'],
+				command_args => ['--', '-'],
 				handles      => $handles );
 			my ($stdout, $stderr, $status) = Echolot::Tools::readwrite_gpg($key{'key'}, $stdin_fh, $stdout_fh, $stderr_fh, $status_fh);
 			waitpid $pid, 0;
@@ -904,8 +903,8 @@ sub build_pgpring_export($$$$) {
 
 	my ( $stdin_fh, $stdout_fh, $stderr_fh, $status_fh, $handles ) = Echolot::Tools::make_gpg_fds();
 	my $pid = $GnuPG->wrap_call(
-		commands     => [ '--export' ],
-		command_args => [qw{--no-options --no-secmem-warning --no-default-keyring --keyring}, $keyring, @$keyids ],
+		commands     => [qw{--no-options --no-secmem-warning --no-default-keyring --keyring}, $keyring, '--export'],
+		command_args => ['--', @$keyids ],
 		handles      => $handles );
 	my ($stdout, $stderr, $status) = Echolot::Tools::readwrite_gpg('', $stdin_fh, $stdout_fh, $stderr_fh, $status_fh);
 	waitpid $pid, 0;
