@@ -1,11 +1,10 @@
 package Echolot::Tools;
 
 #
-# $Id: Tools.pm 661 2004-06-27 17:44:25Z weasel $
 #
 # This file is part of Echolot - a Pinger for anonymous remailers.
 #
-# Copyright (c) 2002, 2003, 2004 Peter Palfrader <peter@palfrader.org>
+# Copyright (c) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2012, 2014 Peter Palfrader <peter@palfrader.org>
 #
 # This program is free software. you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +18,7 @@ package Echolot::Tools;
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 #
 
 =pod
@@ -344,7 +343,7 @@ sub readwrite_gpg($$$$$) {
 			}
 		}
 
-		next unless (defined(@$readyr)); # Wait some more.
+		next unless (defined($readyr)); # Wait some more.
 
 		for my $rfd (@$readyr) {
 			if ($rfd->eof) {
